@@ -399,6 +399,8 @@ destroy_clock(GtkWidget * widget, ClockData *cd)
 		gconf_client_notify_remove (
 				client, cd->listeners [i]);
 
+	g_object_unref (G_OBJECT (client));
+
 	if (cd->timeout > 0) {
 		g_source_remove (cd->timeout);
 		cd->timeout = 0;
@@ -430,6 +432,15 @@ close_on_escape (GtkWidget   *widget,
 	return FALSE;
 }
 
+static gboolean
+delete_event (GtkWidget   *widget,
+	      GdkEvent    *event,
+	      ClockData   *cd)
+{
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cd->toggle), FALSE);
+	return TRUE;
+}
+
 static GtkWidget *
 create_calendar (ClockData *cd,
 		 GdkScreen *screen)
@@ -439,16 +450,14 @@ create_calendar (ClockData *cd,
 
 	window = GTK_WINDOW (gtk_window_new (GTK_WINDOW_TOPLEVEL));
 
-	/* set dialog type so it will skip the tasklist,
-	 * kinda broken. This window should really be override
-	 * redirect I suppose. But I hate override redirect
-	 * windows that don't have a pointer/keyboard grab.
-	 */
-	gtk_window_set_type_hint (window, GDK_WINDOW_TYPE_HINT_DIALOG);
+	gtk_window_set_type_hint (window, GDK_WINDOW_TYPE_HINT_UTILITY);
 	gtk_window_set_decorated (window, FALSE);
 	gtk_window_set_resizable (window, FALSE);
 	gtk_window_stick (window);
 	gtk_window_set_title (window, _("Calendar"));
+
+	g_signal_connect (window, "delete_event",
+			  G_CALLBACK (delete_event), cd);
 			
 	g_signal_connect (window, "key_press_event",
 			  G_CALLBACK (close_on_escape), cd);
@@ -1037,6 +1046,8 @@ setup_gconf (ClockData *clock)
 				(GConfClientNotifyFunc) config_tool_changed,
 				clock, NULL, NULL);
 	g_free (key);
+
+	g_object_unref (G_OBJECT (client));
 }
 
 static gboolean
@@ -1147,6 +1158,8 @@ setup_writability_sensitivity (ClockData *clock, GtkWidget *w, GtkWidget *label,
 	}
 
 	g_free (fullkey);
+
+	g_object_unref (G_OBJECT (client));
 }
 
 static void
