@@ -330,7 +330,7 @@ setup_an_item (AppletUserMenu *menu,
 	if (menu->stock_item && menu->stock_item [0])
 		image = gtk_image_new_from_stock (menu->stock_item, GTK_ICON_SIZE_MENU);
 
-	setup_menuitem (menu->menuitem, GTK_ICON_SIZE_MENU, image, menu->text);
+	setup_menuitem (menu->menuitem, GTK_ICON_SIZE_MENU, image, menu->text, FALSE);
 
 	if(submenu)
 		gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menu->menuitem);
@@ -346,7 +346,7 @@ setup_an_item (AppletUserMenu *menu,
 	/* if the item is a submenu and doesn't have it's menu
 	   created yet*/
 	} else if (!menu->submenu) {
-		menu->submenu = panel_menu_new ();
+		menu->submenu = panel_create_menu ();
 	}
 
 	if(menu->submenu) {
@@ -408,7 +408,7 @@ add_to_submenus (AppletInfo *info,
 	}
 	
 	if (s_menu->submenu == NULL) {
-		s_menu->submenu = panel_menu_new ();
+		s_menu->submenu = panel_create_menu ();
 		/*a more elegant way to do this should be done
 		  when I don't want to go to sleep */
 		if (s_menu->menuitem != NULL) {
@@ -433,7 +433,7 @@ panel_applet_create_menu (AppletInfo  *info,
 	GtkWidget *menuitem;
 	GList     *l;
 
-	menu = g_object_ref (panel_menu_new ());
+	menu = g_object_ref (panel_create_menu ());
 	gtk_object_sink (GTK_OBJECT (menu));
 
 	/* connect the deactivate signal, so that we can "re-allow" 
@@ -472,7 +472,7 @@ panel_applet_create_menu (AppletInfo  *info,
 		menuitem = gtk_image_menu_item_new ();
 		image = gtk_image_new_from_stock (GTK_STOCK_REMOVE,
 						  GTK_ICON_SIZE_MENU);
-		setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, image , _("_Remove From Panel"));
+		setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, image , _("_Remove From Panel"), FALSE);
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (applet_remove_callback), info);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
@@ -480,7 +480,7 @@ panel_applet_create_menu (AppletInfo  *info,
 
 		menuitem = gtk_image_menu_item_new ();
 		image = gtk_image_new ();
-		setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, image, locked ? _("Un_lock") : _("_Lock"));
+		setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, image, locked ? _("Un_lock") : _("_Lock"), FALSE);
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (panel_applet_lock), info);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
@@ -488,7 +488,7 @@ panel_applet_create_menu (AppletInfo  *info,
 		
 		menuitem = gtk_image_menu_item_new ();
 		image = gtk_image_new ();
-		setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, image, _("_Move"));
+		setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, image, _("_Move"), FALSE);
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (move_applet_callback), info);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
@@ -934,10 +934,16 @@ panel_applet_save_position (AppletInfo *applet_info,
 		gconf_client_set_string (client, key, toplevel_id, NULL);
 	g_free (old_toplevel_id);
 
+	/* Note: changing some properties of the panel that may not be locked down
+	   (e.g. background) can change the state of the "panel_right_stick" and
+	   "position" properties of an applet that may in fact be locked down.
+	   So check if these are writable before attempting to write them */
+
 	right_stick = panel_is_applet_right_stick (applet_info->widget) ? 1 : 0;
 	key = panel_gconf_full_key (
 			key_type, profile, id, "panel_right_stick");
-	if (gconf_client_get_bool (client, key, NULL) ? 1 : 0 != right_stick)
+	if (gconf_client_key_is_writable (client, key, NULL) &&
+	    (gconf_client_get_bool (client, key, NULL) ? 1 : 0) != right_stick)
 		gconf_client_set_bool (client, key, right_stick, NULL);
 
 	position = panel_applet_get_position (applet_info);
@@ -945,7 +951,8 @@ panel_applet_save_position (AppletInfo *applet_info,
 		position = panel_widget->size - position;
 
 	key = panel_gconf_full_key (key_type, profile, id, "position");
-	if (gconf_client_get_int (client, key, NULL) != position)
+	if (gconf_client_key_is_writable (client, key, NULL) &&
+	    gconf_client_get_int (client, key, NULL) != position)
 		gconf_client_set_int (client, key, position, NULL);
 	
 	locked = panel_widget_get_applet_locked (panel_widget, applet_info->widget) ? 1 : 0;
