@@ -201,7 +201,8 @@ static GtkWidget * create_add_launcher_menu (GtkWidget *menu,
 static void setup_stock_menu_item     (GtkWidget   *item,
 				       GtkIconSize  icon_size,
 				       const char  *stock_id,
-				       const char  *title);
+				       const char  *title,
+				       gboolean     invisible_mnemonic);
 static gboolean panel_menu_key_press_handler (GtkWidget   *widget,
 					      GdkEventKey *event);
 static void         make_add_submenu   (GtkWidget             *menu,
@@ -327,19 +328,13 @@ about_gnome_cb (GtkWidget *menuitem,
 {
 	GdkScreen *screen = menuitem_to_screen (menuitem);
 
-	if (egg_screen_execute_async (screen, g_get_home_dir (), 1, &program_path) < 0) {
-		char *msg;
-		msg = g_strdup_printf ("<b>%s</b>\n\n%s: %s %s",
-			_("Can't execute 'About GNOME'"),
-			_("Details"), program_path,
-			_("probably does not exist"));
-
+	if (egg_screen_execute_async (screen, g_get_home_dir (), 1, &program_path) < 0)
 		panel_error_dialog (screen,
-		                    "cannot_exec_about_gnome",
-		                    msg);
-
-		g_free (msg);
-	}
+				    "cannot_exec_about_gnome",
+				    _("Cannot execute '%s'"),
+				    _("%s - command not found"),
+				    _("About GNOME"),
+				    program_path);
 }
 
 static void
@@ -358,34 +353,22 @@ activate_app_def (GtkWidget  *menuitem,
 		panel_ditem_launch (
 			item, NULL, 0, menuitem_to_screen (menuitem), &error);
 		if (error) {
-			char *msg;
-			msg = g_strdup_printf ("<b>%s</b>\n\n%s: %s",
-				_("Can't launch entry"),
-				_("Details"), error->message);
+			panel_error_dialog (menuitem_to_screen (menuitem),
+					    "cannot_launch_entry",
+					    _("Cannot launch entry"),
+					    error->message);
 
-			panel_error_dialog (
-				menuitem_to_screen (menuitem),
-				"cant_launch_entry",
-				msg);
-
-			g_free (msg);
 			g_clear_error (&error);
 		}
 		gnome_desktop_item_unref (item);
 	} else {
-		char *msg;
 		g_assert (error != NULL);
 
-		msg = g_strdup_printf ("<b>%s</b>%s: %s",
-			_("Can't load entry"),
-			_("Details"), error->message);
+		panel_error_dialog (menuitem_to_screen (menuitem),
+				    "cannot_load_entry",
+				    _("Cannot load entry"),
+				    error->message);
 
-		panel_error_dialog (
-			menuitem_to_screen (menuitem),
-			"cant_load_entry",
-			msg);
-
-		g_free (msg);
 		g_clear_error (&error);
 	}
 }
@@ -729,33 +712,33 @@ icon_theme_changed (GnomeIconTheme *icon_theme,
 }
 
 GtkWidget *
-panel_menu_new (void)
+panel_create_menu (void)
 {
-	GtkWidget       *menu;
-	static gboolean  registred_icon_theme_changer = FALSE;
+	GtkWidget       *retval;
+	static gboolean  registered_icon_theme_changer = FALSE;
 
-	if (!registred_icon_theme_changer) {
-		registred_icon_theme_changer = TRUE;
+	if (!registered_icon_theme_changer) {
+		registered_icon_theme_changer = TRUE;
 
 		g_signal_connect (panel_icon_theme, "changed",
 				  G_CALLBACK (icon_theme_changed), NULL);
 	}
 	
-	menu = gtk_menu_new ();
-
+	retval = gtk_menu_new ();
+	
 	panel_gconf_notify_add_while_alive ("/desktop/gnome/interface/menus_have_icons",
 					    (GConfClientNotifyFunc) menus_have_icons_changed,
-					    G_OBJECT (menu));
+					    G_OBJECT (retval));
 
-	g_signal_connect_after (menu, "show",
+	g_signal_connect_after (retval, "show",
 				G_CALLBACK (panel_make_sure_menu_within_screen),
 				NULL);
 
-	g_signal_connect (menu, "key_press_event",
+	g_signal_connect (retval, "key_press_event",
 			  G_CALLBACK (panel_menu_key_press_handler),
 			  NULL);
 
-	return menu;
+	return retval;
 }
 
 static GtkWidget *
@@ -763,7 +746,7 @@ menu_new (void)
 {
 	GtkWidget *retval;
 
-	retval = panel_menu_new ();
+	retval = panel_create_menu ();
 
 	g_signal_connect (
 		retval, "show", G_CALLBACK (setup_menu_panel), NULL);
@@ -1076,21 +1059,16 @@ remove_menuitem (GtkWidget *widget, ShowItemMenu *sim)
 	result = gnome_vfs_unlink (sim->item_loc);
 
 	if (result != GNOME_VFS_OK) {
-		char *esc, *msg;
+		char *esc;
 
 		esc = g_markup_escape_text (sim->item_loc, -1);
-		msg = g_strdup_printf ("<b>%s %s</b>\n\n%s: %s\n",
-			_("Could not remove the menu item"),
-			esc,
-			_("Details"),
-			gnome_vfs_result_to_string (result));
 
-		panel_error_dialog (
-			menuitem_to_screen (sim->menuitem),
-			"cant_remove_menu_item",
-			msg);
+		panel_error_dialog (menuitem_to_screen (sim->menuitem),
+				    "cannot_remove_menu_item",
+				    _("Cannot remove menu item %s"),
+				    gnome_vfs_result_to_string (result),
+				    esc);
 
-		g_free (msg);
 		g_free (esc);
 		return;
 	}
@@ -1170,35 +1148,21 @@ add_to_run_dialog (GtkWidget    *widget,
 
 		if (exec != NULL)
 			panel_run_dialog_present_with_text (menuitem_to_screen (sim->menuitem), exec);
-		else {
-			char *msg;
-			msg = g_strdup_printf ("<b>%s</b>\n\n%s",
-				_("Can't add to run box"),
-				_("Details: No 'Exec' or 'URL' field in entry"));
-
-			panel_error_dialog (
-				menuitem_to_screen (sim->menuitem),
-				"no_exec_or_url_field",
-				msg);
-
-			g_free (msg);
-		}
+		else
+			panel_error_dialog (menuitem_to_screen (sim->menuitem),
+					    "no_exec_or_url_field",
+					    _("Cannot add to run box"),
+					    _("No 'Exec' or 'URL' field in entry"));
 
 		gnome_desktop_item_unref (item);
 	} else {
-		char *msg;
 		g_assert (error != NULL);
 
-		msg = g_strdup_printf ("<b>%s</b>\n\n%s: %s",
-			_("Can't load entry"),
-			_("Details"), error->message);
+		panel_error_dialog (menuitem_to_screen (sim->menuitem),
+				    "cannot_load_entry",
+				    _("Cannot load entry"),
+				    error->message);
 
-		panel_error_dialog (
-			menuitem_to_screen (sim->menuitem),
-			"cant_load_entry",
-			msg);
-
-		g_free (msg);
 		g_clear_error (&error);
 	}
 }
@@ -1220,35 +1184,23 @@ show_help_on (GtkWidget    *widget,
 		const char *docpath = gnome_desktop_item_get_string
 			(item, "X-GNOME-DocPath");
 		if ( ! panel_show_gnome_kde_help (screen, docpath, &error)) {
-			char *msg;
-			msg = g_strdup_printf ("<b>%s</b>\n\n%s: %s",
-				_("Cannot display help document"),
-				_("Details"), error->message);
+			panel_error_dialog (screen,
+					    "cannot_show_gnome_kde_help",
+					    _("Cannot display help document"),
+					    error->message);
 
-			panel_error_dialog (
-				screen,
-				"cannot_show_gnome_kde_help",
-				msg);
-
-			g_free (msg);
 			g_clear_error (&error);
 		}
 
 		gnome_desktop_item_unref (item);
 	} else {
-		char *msg;
 		g_assert (error != NULL);
 
-		msg = g_strdup_printf ("<b>%s</b>\n\n%s: %s",
-			_("Can't load entry"),
-			_("Details"), error->message);
+		panel_error_dialog (screen,
+				    "cannot_load_entry",
+				    _("Cannot load entry"),
+				    error->message);
 
-		panel_error_dialog (
-			screen,
-			"cant_load_entry",
-			msg);
-
-		g_free (msg);
 		g_clear_error (&error);
 	}
 }
@@ -1482,7 +1434,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add this launcher to panel"));
+					NULL, _("Add this launcher to panel"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
 			g_signal_connect (menuitem, "activate",
 					  G_CALLBACK (add_app_to_panel),
@@ -1491,7 +1443,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Remove this item"));
+					NULL, _("Remove this item"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
 			g_signal_connect (G_OBJECT(menuitem), "activate",
 					    G_CALLBACK (remove_menuitem),
@@ -1507,7 +1459,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Put into run dialog"));
+					NULL, _("Put into run dialog"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu),
 					       menuitem);
 			g_signal_connect (menuitem, "activate",
@@ -1528,7 +1480,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 				title = g_strdup_printf (_("Help on %s"),
 							 (name != NULL) ? name : _("Application"));
 				setup_menuitem (menuitem, panel_menu_icon_get_size (),
-						NULL, title);
+						NULL, title, FALSE);
 				g_free (title);
 				gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu),
 						 menuitem);
@@ -1553,7 +1505,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 					   G_CALLBACK(edit_dentry),
 					   sim);
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("_Properties"));
+					NULL, _("_Properties"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
 
 			gnome_desktop_item_unref (ii);
@@ -1574,7 +1526,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 				menuitem = gtk_image_menu_item_new ();
 				setup_menuitem (menuitem, panel_menu_icon_get_size (),
-						NULL, _("Entire menu"));
+						NULL, _("Entire menu"), FALSE);
 				gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
 				gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
 							   submenu);
@@ -1583,7 +1535,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (), NULL,
-					_("Add this as drawer to panel"));
+					_("Add this as drawer to panel"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
 			g_signal_connect (G_OBJECT(menuitem), "activate",
 				   G_CALLBACK(add_menudrawer_to_panel),
@@ -1592,7 +1544,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add this as menu to panel"));
+					NULL, _("Add this as menu to panel"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
 			g_signal_connect (G_OBJECT(menuitem), "activate",
 					   G_CALLBACK(add_menu_to_panel),
@@ -1601,7 +1553,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add new item to this menu"));
+					NULL, _("Add new item to this menu"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
 			/*when activated we must pop down the first menu*/
 			g_signal_connect_swapped (G_OBJECT (menuitem),
@@ -1627,7 +1579,7 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 					    G_CALLBACK (edit_direntry),
 					    sim);
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Properties"));
+					NULL, _("Properties"), FALSE);
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
 		}
 	}
@@ -1799,11 +1751,49 @@ image_menuitem_size_request (GtkWidget      *menuitem,
 	requisition->height = MAX (requisition->height, icon_height);
 }
 
+static void
+setup_mnemonic (GtkWidget *menuitem,
+		GtkWidget *old_toplevel,
+		gpointer   keyval_as_pointer)
+{
+	GtkWidget *toplevel;
+	guint      keyval;
+
+	keyval = GPOINTER_TO_UINT (keyval_as_pointer);
+
+	if (old_toplevel != NULL)
+		gtk_window_remove_mnemonic (GTK_WINDOW (old_toplevel),
+					    keyval,
+					    GTK_WIDGET (menuitem));
+
+	toplevel = gtk_widget_get_toplevel (menuitem);
+	if (GTK_WIDGET_TOPLEVEL (toplevel))
+		gtk_window_add_mnemonic (GTK_WINDOW (toplevel),
+					 keyval,
+					 GTK_WIDGET (menuitem));
+}
+
+static void
+setup_invisible_mnemonic (GtkWidget *menuitem,
+			  char       unicode_char)
+{
+	guint accel_key;
+
+	accel_key = gdk_keyval_to_lower (gdk_unicode_to_keyval (unicode_char));
+
+	g_signal_connect (menuitem, "hierarchy_changed", 
+			  G_CALLBACK (setup_mnemonic),
+			  GUINT_TO_POINTER (accel_key));
+
+	setup_mnemonic (menuitem, NULL, GUINT_TO_POINTER (accel_key));
+}
+
 static void
 setup_full_menuitem (GtkWidget   *menuitem,
 		     GtkIconSize  icon_size,
 		     GtkWidget   *image,
 		     const char  *title,
+		     gboolean     invisible_mnemonic,
 		     const char  *item_loc,
 		     MenuFinfo   *mf)
 			       
@@ -1815,8 +1805,11 @@ setup_full_menuitem (GtkWidget   *menuitem,
 	GtkWidget *label;
 
 	label = gtk_label_new_with_mnemonic (title);
-	gtk_misc_set_alignment (GTK_MISC(label), 0.0, 0.5);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_widget_show (label);
+       
+	if (invisible_mnemonic && title)
+		setup_invisible_mnemonic (menuitem, title [0]);
 	
 	gtk_container_add (GTK_CONTAINER (menuitem), label);
 
@@ -1870,9 +1863,10 @@ void
 setup_menuitem (GtkWidget   *menuitem,
 		GtkIconSize  icon_size,
 		GtkWidget   *image,
-		const char  *title)
+		const char  *title,
+		gboolean     invisible_mnemonic)
 {
-	setup_full_menuitem (menuitem, icon_size, image, title, NULL, NULL);
+	setup_full_menuitem (menuitem, icon_size, image, title, invisible_mnemonic, NULL, NULL);
 }
 
 static void
@@ -2180,16 +2174,15 @@ create_menuitem (GtkWidget *menu,
 		 int *first_item,
 		 MenuFinfo *mf)
 {
-	GtkWidget *menuitem, *sub;
-	char *itemname;
+	GtkWidget  *menuitem, *sub;
 	const char *icon, *fallback;
+	char       *itemname;
 	
 	g_return_val_if_fail (fr != NULL, FALSE);
 
 	if(fr->type == FILE_REC_EXTRA)
 		return FALSE;
 
-
 	sub = NULL;
 	if(fr->fullname) {
 		itemname = g_strdup(fr->fullname);
@@ -2248,13 +2241,12 @@ create_menuitem (GtkWidget *menu,
 	if (sub)
 	        setup_full_menuitem (
 			menuitem, panel_menu_icon_get_size (),
-			NULL, itemname, NULL, mf);
+			NULL, itemname, TRUE, NULL, mf);
 
 	else 
 	        setup_full_menuitem (
 			menuitem, panel_menu_icon_get_size(),
-			NULL, itemname, fr->name, mf);
-
+			NULL, itemname, TRUE, fr->name, mf);
 
 	if(*add_separator) {
 		add_menu_separator(menu);
@@ -2422,6 +2414,7 @@ applet_menu_append (GtkWidget  *menu,
 		    gboolean objects_writable)
 {
 	GtkWidget *menuitem;
+	char      *name_with_mnemonic;
 
 	menuitem = gtk_image_menu_item_new ();
 
@@ -2429,7 +2422,9 @@ applet_menu_append (GtkWidget  *menu,
 		panel_load_menu_image_deferred (
 			menuitem, GTK_ICON_SIZE_MENU, applet->stock_icon, applet->icon, NULL, FALSE);
 	
-	setup_full_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, applet->name, NULL, NULL);
+	name_with_mnemonic = g_strconcat ("_", applet->name, NULL);
+	setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, name_with_mnemonic, FALSE);
+	g_free (name_with_mnemonic);
 
 	gtk_widget_show_all (menuitem);
 
@@ -2466,6 +2461,7 @@ applet_menu_append_category (GtkWidget *menu,
 			     const char *stock_icon)
 {
 	GtkWidget *menuitem;
+	char      *category_with_mnemonic;
 
 	menuitem = gtk_image_menu_item_new ();
 
@@ -2473,7 +2469,9 @@ applet_menu_append_category (GtkWidget *menu,
 		panel_load_menu_image_deferred (
 			menuitem, GTK_ICON_SIZE_MENU, stock_icon, NULL, NULL, FALSE);
 
-	setup_full_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, category, NULL, NULL);
+	category_with_mnemonic = g_strconcat ("_", category, NULL);
+	setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, category_with_mnemonic, FALSE);
+	g_free (category_with_mnemonic);
 
 	gtk_widget_show_all (menuitem);
 
@@ -2794,13 +2792,14 @@ static void
 setup_stock_menu_item (GtkWidget   *item,
 		       GtkIconSize  icon_size,
 		       const char  *stock_id,
-		       const char  *title)
+		       const char  *title,
+		       gboolean     invisible_mnemonic)
 {
 	if (stock_id)
 		panel_load_menu_image_deferred (
 			item, icon_size, stock_id, NULL, NULL, FALSE);
 
-	setup_menuitem (item, icon_size, NULL, title);
+	setup_menuitem (item, icon_size, NULL, title, invisible_mnemonic);
 }
 	  
 static GtkWidget *
@@ -2914,10 +2913,10 @@ remove_panel (GtkWidget *menuitem,
 	toplevel     = panel_widget->toplevel;
 
 	if (panel_toplevel_is_last_unattached (toplevel)) {
-		panel_error_dialog (
-			menuitem_to_screen (menuitem),
-			"cannot_remove_last_panel",
-			_("You cannot remove your last panel."));
+		panel_error_dialog (menuitem_to_screen (menuitem),
+				    "cannot_remove_last_panel",
+				    _("You cannot remove your last panel."),
+				    NULL);
 		return;
 	}
 
@@ -2996,7 +2995,8 @@ make_panel_submenu (PanelWidget *panel_widget,
 	setup_menuitem (menuitem,
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU),
-			_("_Add to Panel"));
+			_("_Add to Panel"),
+			FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 
 	submenu = menu_new ();
@@ -3020,7 +3020,8 @@ make_panel_submenu (PanelWidget *panel_widget,
 	setup_menuitem (menuitem, 
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU),
-			_("_Delete This Panel"));
+			_("_Delete This Panel"),
+			FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (G_OBJECT (menuitem), "activate",
 			    G_CALLBACK (remove_panel),
@@ -3034,7 +3035,8 @@ make_panel_submenu (PanelWidget *panel_widget,
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (
 				GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_MENU),
-			_("_Properties"));
+			_("_Properties"),
+			FALSE);
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect_swapped (menuitem, "activate",
@@ -3047,7 +3049,8 @@ make_panel_submenu (PanelWidget *panel_widget,
 	setup_menuitem (menuitem, 
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU),
-			_("_New Panel"));
+			_("_New Panel"),
+			FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (create_new_panel), 
@@ -3084,7 +3087,8 @@ create_panel_context_menu (PanelWidget *panel)
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (
 				GTK_STOCK_HELP, GTK_ICON_SIZE_MENU),
-			_("_Help"));
+			_("_Help"),
+			FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (retval), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (show_panel_help), NULL);
@@ -3094,7 +3098,8 @@ create_panel_context_menu (PanelWidget *panel)
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (
 				GNOME_STOCK_ABOUT, GTK_ICON_SIZE_MENU),
-			_("_About Panels"));
+			_("_About Panels"),
+			FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (retval), menuitem);
 	g_signal_connect (menuitem, "activate", G_CALLBACK (show_about_dialog), NULL);
 	
@@ -3107,7 +3112,8 @@ create_panel_context_menu (PanelWidget *panel)
 				GTK_ICON_SIZE_MENU,
 				gtk_image_new_from_stock (
 					GNOME_STOCK_ABOUT, GTK_ICON_SIZE_MENU),
-				_("About _GNOME"));
+				_("About _GNOME"),
+				FALSE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (retval), menuitem);
 		g_signal_connect_data (menuitem, "activate",
 				       G_CALLBACK (about_gnome_cb),
@@ -3150,7 +3156,7 @@ make_add_submenu (GtkWidget             *menu,
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher..."));
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("_Launcher..."), FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (G_OBJECT(menuitem), "activate",
 			   G_CALLBACK(ask_about_launcher_cb),NULL);
@@ -3159,7 +3165,7 @@ make_add_submenu (GtkWidget             *menu,
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher from menu"));
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher _from menu"), FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	m = create_add_launcher_menu (NULL, TRUE);
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), m);
@@ -3169,7 +3175,7 @@ make_add_submenu (GtkWidget             *menu,
 
   	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_GNOME_LOGO, _("Main Menu"));
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_MAIN_MENU, _("Main _Menu"), FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (G_OBJECT(menuitem), "activate",
 			   G_CALLBACK(add_menu_to_panel),
@@ -3179,7 +3185,7 @@ make_add_submenu (GtkWidget             *menu,
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_GNOME_LOGO, _("Menu Bar"));
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_GNOME_LOGO, _("Menu _Bar"), FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (add_menu_bar_to_panel), NULL);
@@ -3188,7 +3194,7 @@ make_add_submenu (GtkWidget             *menu,
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_DRAWER, _("Drawer"));
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_DRAWER, _("_Drawer"), FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (G_OBJECT(menuitem), "activate",
 			   (GtkSignalFunc) add_drawer_to_panel,
@@ -3211,7 +3217,7 @@ create_desktop_menu (GtkWidget *menu, gboolean fake_submenus)
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_LOCKSCREEN, _("Lock Screen"));
+			PANEL_STOCK_LOCKSCREEN, _("Lock Screen"), TRUE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (panel_action_lock_screen), NULL);
@@ -3223,7 +3229,7 @@ create_desktop_menu (GtkWidget *menu, gboolean fake_submenus)
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, panel_menu_icon_get_size (), PANEL_STOCK_LOGOUT, _("Log Out"));
+		menuitem, panel_menu_icon_get_size (), PANEL_STOCK_LOGOUT, _("Log Out"), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (panel_action_logout), 0);
@@ -3257,7 +3263,8 @@ add_distribution_submenu (GtkWidget *root_menu, gboolean fake_submenus,
 	setup_stock_menu_item (menuitem,
 			       panel_menu_icon_get_size (),
 			       distribution_info->stock_icon,
-			       _(distribution_info->menu_name));
+			       _(distribution_info->menu_name),
+			       TRUE);
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
@@ -3286,7 +3293,7 @@ add_kde_submenu (GtkWidget *root_menu, gboolean fake_submenus,
 	panel_load_menu_image_deferred (
 		menuitem, panel_menu_icon_get_size (), PANEL_STOCK_KDE, NULL, NULL, FALSE);
 
-	setup_menuitem (menuitem, panel_menu_icon_get_size (), NULL, _("KDE Menu"));
+	setup_menuitem (menuitem, panel_menu_icon_get_size (), NULL, _("KDE Menu"), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
 	g_signal_connect (G_OBJECT(menu),"show",
@@ -3361,7 +3368,7 @@ create_root_menu (GtkWidget   *root_menu,
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_GNOME_LOGO, _("Applications"));
+			PANEL_STOCK_GNOME_LOGO, _("Applications"), TRUE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
 		if(menu) {
 			gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
@@ -3386,7 +3393,7 @@ create_root_menu (GtkWidget   *root_menu,
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_RUN, _("Run Application..."));
+			PANEL_STOCK_RUN, _("Run Application..."), TRUE);
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (panel_action_run_program),
 				  NULL);
@@ -3402,7 +3409,7 @@ create_root_menu (GtkWidget   *root_menu,
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_SEARCHTOOL, _("Search for Files..."));
+			PANEL_STOCK_SEARCHTOOL, _("Search for Files..."), TRUE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
 		gtk_tooltips_set_tip (panel_tooltips, menuitem,
 				      _("Find files, folders, and documents "
@@ -3421,7 +3428,7 @@ create_root_menu (GtkWidget   *root_menu,
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_SCREENSHOT, _("Take Screenshot..."));
+			PANEL_STOCK_SCREENSHOT, _("Take Screenshot..."), TRUE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
 		gtk_tooltips_set_tip (panel_tooltips, menuitem,
 				      _("Take a screenshot of your desktop"),
@@ -3439,7 +3446,7 @@ create_root_menu (GtkWidget   *root_menu,
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_DESKTOP, _("Desktop"));
+			PANEL_STOCK_DESKTOP, _("Desktop"), TRUE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
 	}
