@@ -21,7 +21,8 @@ enum {
 void		setup_menuitem		(GtkWidget        *menuitem,
 					 GtkIconSize       icon_size,
 					 GtkWidget        *pixmap,
-					 const char       *title);
+					 const char       *title,
+					 gboolean          invisible_mnemonic);
 
 GtkWidget      *create_menu_at          (GtkWidget     *menu,
 					 const char    *menudir,
@@ -51,7 +52,7 @@ GtkWidget *	create_root_menu	(GtkWidget   *root_menu,
 /* some gtk code cut-n-paste action */
 void		our_gtk_menu_position	(GtkMenu *menu);
 
-GtkWidget *	panel_menu_new		(void);
+GtkWidget *	panel_create_menu              (void);
 void		panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 						GtkIconSize  icon_size,
 						const char  *stock_id,
