@@ -31,7 +31,7 @@
 G_BEGIN_DECLS
 
 /* themeable size - "panel-menu" */
-#define PANEL_DEFAULT_MENU_ICON_SIZE 	20 
+#define PANEL_DEFAULT_MENU_ICON_SIZE 	24
 #define PANEL_DEFAULT_BUTTON_ICON_SIZE  12
 
 /* stock icons */
@@ -40,7 +40,9 @@ G_BEGIN_DECLS
 #define PANEL_STOCK_SCREENSHOT          "panel-screenshot"
 #define PANEL_STOCK_LOCKSCREEN          "panel-lockscreen"
 #define PANEL_STOCK_LOGOUT              "panel-logout"
+#define PANEL_STOCK_FORCE_QUIT          "panel-force-quit"
 #define PANEL_STOCK_GNOME_LOGO          "panel-gnome-logo"
+#define PANEL_STOCK_MAIN_MENU           "panel-main-menu"
 #define PANEL_STOCK_DEBIAN              "panel-debian"
 #define PANEL_STOCK_SUSE                "panel-suse"
 #define PANEL_STOCK_CDE                 "panel-cde"
